# jsonl2json

Converts jsonlines file to json file, by converting it into array of json objects.

## Install

###### Recommended (To install pipx click [here](https://github.com/pypa/pipx#install-pipx))

```sh
pipx install jsonl2json-aq
```

###### or

```sh
pip install jsonl2json-aq
```

#### Or upgrade by

```sh
pipx upgrade jsonl2json-aq
```

###### or

```sh
pip install --upgrade jsonl2json-aq
```

## Usage

```sh
jl2j input_file output_file
```

## Install from source

Poetry is required. For installation click [here](https://python-poetry.org/docs/#installation).

Download the source and install the dependencies by running:

```sh
git clone https://github.com/aqdasak/jsonl2json.git
cd jsonl2json
poetry install
```

## License

This project is licensed under the MIT License.
